<?php

class Elementor_pishro_blog extends \Elementor\Widget_Base
{


    public function get_name()
    {
        return 'pishro_blog';
    }


    public function get_title()
    {
        return 'مقالات';
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }


    public function get_categories()
    {
        return ['pishro'];
    }

    public function get_keywords()
    {
        return ['product','article','post','blog'];
    }
    function get_cats()
    {
        $cats = [ 'all' => 'همه' ];
        $categories = get_categories();
        foreach ( $categories as $category )
        {
            $cats[ $category->cat_ID ] = $category->name;
        }

        return $cats;
    }


    protected function register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'المان محصولات', 'textdomain' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'label'       => __('عنوان','pishro'),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'input_type'  => 'text',
                'placeholder' => '',
                'default' => 'وبلاگ پیشرو',
            ]
        );
        $this->add_control(
            'link',
            [
                'type' => \Elementor\Controls_Manager::URL,
                'options' => [ 'url', 'is_external', 'nofollow' ],
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => false,
                    // 'custom_attributes' => '',
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'cat',
            [
                'label'   => 'دسته بندی',
                'type' => \Elementor\Controls_Manager::SELECT,

                'label_block' => true,
                'options' => $this->get_cats(),
            ]
        );



        $this->end_controls_section();

        
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $cat = $settings['cat'];

        ?>
        <section class="hero-blog">
            <div class="container">
                <?php if ($settings['title']) { ?>
                    <header class="title-hero">
                        <?php
                        $target = $settings['link']['is_external'] ? 'target="_blank"' : '';
                        $nofollw = $settings['link']['nofollow'] ? 'rel="nofollow"' : '';
                        ?>
                        <h4><a <?php echo $target,$nofollw ?> href="<?php echo $settings['link']['url']; ?>" target="_blank"><?php echo $settings['title']; ?></a></h4>
                    </header>
                <?php } ?>
                <div class="box-blog">

                    <?php
                    $big_post = new WP_Query(array(
                        'post_type' => 'post',
                        'posts_per_page' => 1,
                        'no_found_rows' => 1,
                        'cat'   => $cat,
                    ));
                    if ($big_post->have_posts()) {
                        while ($big_post->have_posts()) : $big_post->the_post(); ?>

                            <div class="big-post">
                                <a href="<?php the_permalink(); ?>" target="_blank">
                                    <figure>
                                        <?php
                                        if (has_post_thumbnail()) {
                                            the_post_thumbnail('big-post');
                                        } else {
                                            ?><img src="<?php echo get_template_directory_uri() . '/img/0.jpg' ?>"> <?php
                                        }
                                        ?>
                                    </figure>
                                    <div class="title">
                                        <h2><?php the_title(); ?>
                                            <i class="fa-solid fa-arrow-left"></i>
                                        </h2>
                                    </div>

                                </a>

                            </div>
                        <?php
                        endwhile;
                    } else {
                        echo "<p>مطلبی پیدا نشد</p>";
                    }
                    wp_reset_postdata();
                    ?>


                    <div class="small-post">
                        <?php
                        $small_post = new WP_Query(array(
                            'post_type' => 'post',
                            'posts_per_page' => 4,
                            'offset' => 1,
                            'relation' => 'OR',
                            'no_found_rows' => 1,
                            'cat'   => $cat,
                        ));
                        if ($small_post->have_posts()) {
                            while ($small_post->have_posts()) : $small_post->the_post(); ?>
                                <div class="post-item">
                                    <a href="<?php the_permalink(); ?>" target="_blank">
                                        <figure>
                                            <?php
                                            if (has_post_thumbnail()) {
                                                the_post_thumbnail('small-post');
                                            } else {
                                                ?><img src="<?php echo get_template_directory_uri() . '/img/0.jpg' ?>"> <?php
                                            }
                                            ?>
                                        </figure>
                                        <h2><?php the_title(); ?></h2>
                                        <div class="down">
                                            <span><?php the_time(' d F Y'); ?></span>
                                            <i class="fa-solid fa-arrow-left"></i>
                                        </div>
                                    </a>
                                </div>
                            <?php
                            endwhile;
                        } else {
                            echo "<p>مطلبی پیدا نشد</p>";
                        }
                        wp_reset_postdata();
                        ?>
                    </div>

                </div>
            </div>
        </section>
        <?php
    }

}