<?php

class Elementor_pishro_product extends \Elementor\Widget_Base
{


    public function get_name()
    {
        return 'pishro_product';
    }


    public function get_title()
    {
        return 'نمایش محصولات';
    }

    public function get_icon()
    {
        return 'eicon-products';
    }


    public function get_categories()
    {
        return ['pishro'];
    }

    public function get_keywords()
    {
        return ['product'];
    }
    function get_product_cats(){
        $cat_list = [];
        $product_cats = get_terms( array(
            'taxonomy' => 'product_cat',
            'hide_empty' => true,
        ));

        if ( ! empty( $product_cats ) && ! is_wp_error( $product_cats ) ){
            foreach ( $product_cats as $cat ) {
                $cat_list[ $cat->term_id ] = $cat->name;
            }
        }
        return $cat_list;
    }
    function get_product_tags(){
        $tag_list = [];
        $product_tags = get_terms('product_tag');

        if ( ! empty( $product_tags ) && ! is_wp_error( $product_tags ) ){
            foreach ( $product_tags as $tag ) {
                $tag_list[ $tag->term_id ] = $tag->name;
            }
        }
        return $tag_list;
    }
    function get_product_brands(){
        $brand_list = [];
        $product_brands = get_terms('product_brand');

        if ( ! empty( $product_brands ) && ! is_wp_error( $product_brands ) ){
            foreach ( $product_brands as $brand ) {
                $brand_list[ $brand->term_id ] = $brand->name;
            }
        }
        return $brand_list;
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'المان محصولات', 'textdomain' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'label'       => __('عنوان','pishro'),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'input_type'  => 'text',
                'placeholder' => '',
                'default' => 'جدیدترین محصولات پیشرو',
            ]
        );
        $this->add_control(
            'link',
            [
                'type' => \Elementor\Controls_Manager::URL,
                'options' => [ 'url', 'is_external', 'nofollow' ],
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => false,
                    // 'custom_attributes' => '',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'product_style',
            [
                'label' => 'سبک نمایش',
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'style1',
                'options' => [
                    'style1' 	 	=> 'سبک 1',
                    'style2' 	 	=> 'سبک 2',
                ],
            ]
        );
        $this->add_control(
            'product_filter',
            [
                'label' => 'فیلتر محصولات',
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'all',
                'options' => [
                    'all' 	 	=> 'همه محصولات',
                    'category' 	 	=> 'براساس دسته بندی',
                    'tag' 			=> 'براساس برچسب',
                    'brand' 		=> 'براساس برند',
                ],
            ]
        );
        $this->add_control(
            'cat',
            [
                'label'   => 'دسته بندی',
                'type' => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'label_block' => true,
                'options' => $this->get_product_cats(),
                'condition' => [
                    'product_filter' => 'category',
                ],
            ]
        );
        $this->add_control(
            'tag',
            [
                'label'   => 'برچسب',
                'type' => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'label_block' => true,
                'options' => $this->get_product_tags(),
                'condition' => [
                    'product_filter' => 'tag',
                ],
            ]
        );
        $this->add_control(
            'brand',
            [
                'label'   => 'برند',
                'type' => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'label_block' => true,
                'options' => $this->get_product_brands(),
                'condition' => [
                    'product_filter' => 'brand',
                ],
            ]
        );

        $this->add_control(
            'number',
            [
                'label' => 'تعداد محصولات',
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 40,
                'step' => 1,
                'default' => 6,
            ]
        );
        $this->add_control(
            'item_slide',
            [
                'label' => 'تعداد آیتم های اسلایدر',
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 4,
                'max' => 6,
                'step' => 1,
                'default' => 5,
            ]
        );
		$this->add_control(
            'show_nav',
            [
                'label' => 'نمایش پیکان ها',
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'نمایش', 'textdomain' ),
                'label_off' => esc_html__( 'مخفی', 'textdomain' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'attr',
            [
                'label' => 'نمایش ویژگی ها',
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'نمایش', 'textdomain' ),
                'label_off' => esc_html__( 'مخفی', 'textdomain' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'stock',
            [
                'label' => 'حذف محصولات ناموجود',
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => 'فعال',
                'label_off' => 'غیرفعال',
                'return_value' => 'yes',
                'default' => '',
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $filter = $settings['product_filter'];
		
		
        ?>
        <section class="hero-product">
            <div class="container">
                <?php if ($settings['title']) { ?>
                <header class="title-hero">
                    <?php
                    $target = $settings['link']['is_external'] ? 'target="_blank"' : '';
                    $nofollw = $settings['link']['nofollow'] ? 'rel="nofollow"' : '';
                    ?>
                    <h4><a <?php echo $target,$nofollw ?> href="<?php echo $settings['link']['url']; ?>" target="_blank"><?php echo $settings['title']; ?></a></h4>
                </header>
                <?php } ?>
                <div class="owl-carousel owl-theme product-slider">

                    <?php
                    $product_args = array(
                        'post_type' => 'product',
                        'posts_per_page' => $settings['number'],
                    );
                    if ($settings['product_filter']=='category') {
                        $tax_query = array(
                            'relation' => 'OR',
                            array(
                                'taxonomy' => 'product_cat',
                                'field' => 'term_id',
                                'terms' => $settings['cat'],
                            ),
                        );
                        $product_args['tax_query'] = $tax_query;
                    }
                    elseif ($settings['product_filter']=='tag') {
                        $tax_query = array(
                            'relation' => 'OR',
                            array(
                                'taxonomy' => 'product_tag',
                                'field' => 'term_id',
                                'terms' => $settings['tag'],
                            ),
                        );
                        $product_args['tax_query'] = $tax_query;
                    }
                    elseif ($settings['product_filter']=='brand') {
                        $tax_query = array(
                            'relation' => 'OR',
                            array(
                                'taxonomy' => 'product_brand',
                                'field' => 'term_id',
                                'terms' => $settings['brand'],
                            ),
                        );
                        $product_args['tax_query'] = $tax_query;
                    }
                    if ($settings['stock']) {
                        $meta_query = array(
                            array(
                                'key'     => '_stock_status',
                                'value'   => 'instock',
                                'compare' => '=',
                            ),
                        );
                        $product_args['meta_query'] = $meta_query;
                    }
                    $pro = new WP_Query($product_args);
                    if ($pro->have_posts()) {
                        while ($pro->have_posts()) : $pro->the_post();

                            ?>
                            <div class="item product-item">
                                <?php
                                global $product;

                                if ($settings['attr']) {
                                $attribute_taxonomies =  wc_get_attribute_taxonomies();
                                foreach ($attribute_taxonomies as $item) {
                                    $att_name = $item->attribute_name;
                                    $terms = get_the_terms(get_the_ID(), 'pa_'.$att_name);

                                    if (is_array($terms)) {
                                        ?>
                                        <div class="color">
                                            <ul>
                                                <?php
                                                foreach ($terms as $term) :
                                                    $tooltip = $term->name;
                                                    // بالایی ترم بود این متاهای ترمه
                                                    $colors = get_term_meta( $term->term_id, 'product_attribute_color', 1 );
                                                    //$colors = get_term_meta( $term->term_id, 'wpcvs_color', true );
                                                    ?>
                                                    <li>
                                                        <?php if ($colors) { ?>
                                                            <span style="background: <?php echo $colors; ?>">
                                        <b><?php echo $tooltip; ?></b>
                                    </span>
                                                            <?php
                                                        }
                                                        else { ?>
                                                            <small><?php echo $tooltip; ?></small>
                                                        <?php } ?>
                                                    </li>
                                                <?php endforeach; ?>
                                            </ul>
                                        </div>
                                    <?php }

                                }
                                }
                                ?>



                                <?php if($product->is_on_sale()){ ?>
                                    <div class="discount">
                                        <?php echo pishro_wooocmmerce_discount(get_the_ID()) ?>٪
                                    </div>
                                <?php } ?>

                                <?php //echo do_shortcode("[acoqvw_quickview]"); ?>

                                <figure class="product-thumbnails">
                                    <a href="<?php the_permalink(); ?>" target="_blank">
                                        <?php

                                        $arr = array(200,200);
                                        echo (has_post_thumbnail() ? get_the_post_thumbnail(get_the_id(), array(200, 200), array('class' => 'main-img')) : wc_placeholder_img('woocommerce_thumbnail'));
                                        pishro_second_thumbnail($arr);
                                        ?>
                                    </a>
                                </figure>
                                <h2><a href="<?php the_permalink(); ?>" target="_blank"><?php the_title(); ?></a></h2>

                                <?php if ($settings['product_style']=="style1") { ?>
                                <div class="down">
                                    <?php
                                    if ($product->is_in_stock()) : ?>
                                        <div class="add_to_cart_button"><?php
                                            echo sprintf('<a href="%s" data-quantity="1" class="%s" %s><i class="fa-solid fa-circle-plus"></i></a>',
                                                esc_url($product->add_to_cart_url()),
                                                esc_attr(implode(' ', array_filter(array(
                                                    'button', 'product_type_' . $product->get_type(),
                                                    $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
                                                    $product->supports('ajax_add_to_cart') ? 'ajax_add_to_cart' : '',
                                                )))),
                                                wc_implode_html_attributes(array(
                                                    'data-product_id' => $product->get_id(),
                                                    'data-product_sku' => $product->get_sku(),
                                                    'aria-label' => $product->add_to_cart_description(),
                                                    'rel' => 'nofollow',
                                                )),
                                                esc_html($product->add_to_cart_text())
                                            );
                                            ?></div>
                                        <?php if ($product->get_price_html()) : ?>
                                            <?php if( $product->is_type( 'simple' ) ) : ?>
                                                <div class="price"><?php echo $product->get_price_html(); ?></div>
                                            <?php else : ?>
                                                <div class="price-variable"><div class="price"><?php echo $product->get_price_html(); ?></div></div>
                                            <?php endif; ?>
                                        <?php else : ?>
                                            <div style="font-weight: 600;">تماس بگیرید</div>
                                        <?php endif; ?>
                                    <?php else: ?>
                                        <div class="not_stock"><i class="fa-solid fa-multiply"></i>موجود نیست !</div>
                                    <?php endif;?>

                                </div>
                                <?php } else { ?>
                                <div class="down down-two">
                                    <?php
                                    if ($product->is_in_stock()) : ?>
                                        <?php if ($product->get_price_html()) : ?>
                                            <div class="price"><?php echo $product->get_price_html(); ?></div>
                                        <?php else : ?>
                                            <div style="font-weight: 600;">تماس بگیرید</div>
                                        <?php endif; ?>
                                    <?php else: ?>
                                        <div class="not_stock"><i class="fa-solid fa-multiply"></i>موجود نیست !</div>
                                    <?php endif;?>

                                    <div class="wish-add">
                                        <div class="add-to-cart">
                                            <?php
                                            echo sprintf('<a href="%s" data-quantity="1" class="%s" %s> %s</a>',
                                                esc_url($product->add_to_cart_url()),
                                                esc_attr(implode(' ', array_filter(array(
                                                    'button', 'product_type_' . $product->get_type(),
                                                    $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
                                                    $product->supports('ajax_add_to_cart') ? 'ajax_add_to_cart' : '',
                                                )))),
                                                wc_implode_html_attributes(array(
                                                    'data-product_id' => $product->get_id(),
                                                    'data-product_sku' => $product->get_sku(),
                                                    'aria-label' => $product->add_to_cart_description(),
                                                    'rel' => 'nofollow',
                                                )),
                                                esc_html($product->add_to_cart_text())
                                            );
                                            ?>
                                        </div>
                                        <div class="wishlist-button">
                                            <?php
                                            $id = $product->id;
                                            echo do_shortcode("[woosw id=$id]") ?>
                                        </div>
                                    </div>

                                </div>
                                <?php } ?>


                            </div>
                        <?php
                        endwhile;
                    } else {
                        echo "<p>مطلبی پیدا نشد</p>";
                    }
                    wp_reset_postdata();
                    ?>
                </div>
            </div>
        </section>

        <script>
            jQuery(function (){
                jQuery('.product-slider').owlCarousel({
                    loop:true,
                    margin:0,
                    dots:false,
                    nav:<?php if ($settings['show_nav']){echo "true";} else {echo "false"; } ?>,
                    navText:"",
                    rtl: true,
                    responsive:{
                        0:{
                            items:1
                        },
                        576:{
                            items:2
                        },
                        768:{
                            items:3
                        },
                        992:{
                            items:4
                        },
                        1200:{
                            items:<?php echo $settings['item_slide']; ?>
                        }
                    }
                })
            });

        </script>

        <?php
    }

}